==> crossfire-0.91.8.tar.gz: crossfire-0.91.8/include/bitmaps.h <==
/*
 * static char *rcsid_bitmaps_h =
 *   "$Id: bitmaps.h,v 1.11 1994/03/29 08:41:16 master Exp $";
 */

/*
    CrossFire, A Multiplayer game for X-windows

    Copyright (C) 1992 Frank Tore Johansen

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    The author can be reached via e-mail to frankj@ifi.uio.no.
*/

#define crossfire_width 60
#define crossfire_height 60
static unsigned char crossfire_bits[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x07, 0x00, 0x00, 0x1e, 0x00, 0x00,
   0x00, 0x80, 0x08, 0x00, 0x00, 0x11, 0x00, 0x00, 0x00, 0x80, 0x34, 0x00,
   0x80, 0x10, 0x00, 0x00, 0x00, 0x80, 0x40, 0x00, 0x60, 0x12, 0x00, 0x00,
   0x00, 0x00, 0x91, 0x00, 0x10, 0x09, 0x00, 0x00, 0x00, 0x00, 0x36, 0x01,
   0x08, 0x06, 0x00, 0x00, 0x00, 0x00, 0x08, 0x06, 0x24, 0x01, 0x00, 0x00,
   0x00, 0x00, 0x10, 0x09, 0x93, 0x00, 0x00, 0x00, 0x00, 0x00, 0x20, 0x90,
   0x44, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x64, 0x32, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x80, 0xc1, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x32,
   0x05, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x02, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x8a, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x31,
   0x09, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x60, 0x30, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x20, 0x91, 0x48, 0x00, 0x00, 0x00, 0x00, 0x00, 0x90, 0x08,
   0x81, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x06, 0x46, 0x01, 0x00, 0x00,
   0x00, 0x00, 0x26, 0x01, 0x08, 0x06, 0x00, 0x00, 0x00, 0x00, 0x91, 0x00,
   0x10, 0x09, 0x00, 0x00, 0x00, 0x80, 0x40, 0x00, 0x20, 0x10, 0x00, 0x00,
   0x00, 0x40, 0x32, 0x00, 0x40, 0x24, 0x00, 0x00, 0x00, 0x30, 0x09, 0x00,
   0x80, 0xc1, 0x00, 0x00, 0x40, 0x08, 0x04, 0x00, 0x00, 0x32, 0x21, 0x00,
   0x80, 0x24, 0x02, 0x00, 0x00, 0x04, 0x12, 0x00, 0x00, 0x93, 0x01, 0x00,
   0x00, 0x88, 0x0c, 0x00, 0x00, 0x43, 0x00, 0x00, 0x00, 0x30, 0x0c, 0x00,
   0xc0, 0x27, 0x00, 0x00, 0x00, 0x40, 0x3e, 0x00, 0xe0, 0x1f, 0x00, 0x00,
   0x00, 0x80, 0x7f, 0x00, 0xf0, 0x1f, 0x00, 0x00, 0x00, 0x80, 0xff, 0x00,
   0xf8, 0x27, 0x00, 0x00, 0x00, 0x40, 0xfe, 0x01, 0xf8, 0x43, 0x00, 0x00,
   0x00, 0x20, 0xfc, 0x01, 0xf8, 0x01, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x01,
   0xf0, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x00, 0x60, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0xfc, 0x03, 0x00, 0x00, 0xe0, 0x1f, 0x00, 0x00,
   0x04, 0x02, 0x00, 0x00, 0x20, 0x00, 0x00, 0x00, 0x04, 0x02, 0x00, 0x00,
   0x20, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 0x20, 0x00, 0x00, 0x00,
   0x04, 0x00, 0x00, 0x00, 0x20, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00,
   0xe0, 0x01, 0x00, 0x00, 0x04, 0xf0, 0x79, 0x9e, 0x27, 0x90, 0xcf, 0x03,
   0x04, 0x10, 0x49, 0x82, 0x20, 0x90, 0x48, 0x00, 0x04, 0xf2, 0x49, 0x9e,
   0x27, 0x90, 0xcf, 0x01, 0x04, 0x92, 0x48, 0x10, 0x24, 0x90, 0x44, 0x00,
   0xfc, 0x93, 0x79, 0x9e, 0x27, 0x90, 0xcc, 0x03, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00};

==> crossfire-0.93.2.tar.gz: crossfire-0.93.2/include/bitmaps.h <==
/*
 * static char *rcsid_bitmaps_h =
 *   "$Id: bitmaps.h,v 1.12 1997/01/05 09:56:59 master Exp $";
 */

/*
    CrossFire, A Multiplayer game for X-windows

    Copyright (C) 1992 Frank Tore Johansen

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    The author can be reached via e-mail to mark@pyramid.com.
*/

#define crossfire_width 60
#define crossfire_height 60
static unsigned char crossfire_bits[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x07, 0x00, 0x00, 0x1e, 0x00, 0x00,
   0x00, 0x80, 0x08, 0x00, 0x00, 0x11, 0x00, 0x00, 0x00, 0x80, 0x34, 0x00,
   0x80, 0x10, 0x00, 0x00, 0x00, 0x80, 0x40, 0x00, 0x60, 0x12, 0x00, 0x00,
   0x00, 0x00, 0x91, 0x00, 0x10, 0x09, 0x00, 0x00, 0x00, 0x00, 0x36, 0x01,
   0x08, 0x06, 0x00, 0x00, 0x00, 0x00, 0x08, 0x06, 0x24, 0x01, 0x00, 0x00,
   0x00, 0x00, 0x10, 0x09, 0x93, 0x00, 0x00, 0x00, 0x00, 0x00, 0x20, 0x90,
   0x44, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x64, 0x32, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x80, 0xc1, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x32,
   0x05, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x02, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x8a, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x31,
   0x09, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x60, 0x30, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x20, 0x91, 0x48, 0x00, 0x00, 0x00, 0x00, 0x00, 0x90, 0x08,
   0x81, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x06, 0x46, 0x01, 0x00, 0x00,
   0x00, 0x00, 0x26, 0x01, 0x08, 0x06, 0x00, 0x00, 0x00, 0x00, 0x91, 0x00,
   0x10, 0x09, 0x00, 0x00, 0x00, 0x80, 0x40, 0x00, 0x20, 0x10, 0x00, 0x00,
   0x00, 0x40, 0x32, 0x00, 0x40, 0x24, 0x00, 0x00, 0x00, 0x30, 0x09, 0x00,
   0x80, 0xc1, 0x00, 0x00, 0x40, 0x08, 0x04, 0x00, 0x00, 0x32, 0x21, 0x00,
   0x80, 0x24, 0x02, 0x00, 0x00, 0x04, 0x12, 0x00, 0x00, 0x93, 0x01, 0x00,
   0x00, 0x88, 0x0c, 0x00, 0x00, 0x43, 0x00, 0x00, 0x00, 0x30, 0x0c, 0x00,
   0xc0, 0x27, 0x00, 0x00, 0x00, 0x40, 0x3e, 0x00, 0xe0, 0x1f, 0x00, 0x00,
   0x00, 0x80, 0x7f, 0x00, 0xf0, 0x1f, 0x00, 0x00, 0x00, 0x80, 0xff, 0x00,
   0xf8, 0x27, 0x00, 0x00, 0x00, 0x40, 0xfe, 0x01, 0xf8, 0x43, 0x00, 0x00,
   0x00, 0x20, 0xfc, 0x01, 0xf8, 0x01, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x01,
   0xf0, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x00, 0x60, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0xfc, 0x03, 0x00, 0x00, 0xe0, 0x1f, 0x00, 0x00,
   0x04, 0x02, 0x00, 0x00, 0x20, 0x00, 0x00, 0x00, 0x04, 0x02, 0x00, 0x00,
   0x20, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 0x20, 0x00, 0x00, 0x00,
   0x04, 0x00, 0x00, 0x00, 0x20, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00,
   0xe0, 0x01, 0x00, 0x00, 0x04, 0xf0, 0x79, 0x9e, 0x27, 0x90, 0xcf, 0x03,
   0x04, 0x10, 0x49, 0x82, 0x20, 0x90, 0x48, 0x00, 0x04, 0xf2, 0x49, 0x9e,
   0x27, 0x90, 0xcf, 0x01, 0x04, 0x92, 0x48, 0x10, 0x24, 0x90, 0x44, 0x00,
   0xfc, 0x93, 0x79, 0x9e, 0x27, 0x90, 0xcc, 0x03, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00};
